@@ -61,10 +61,10 @@
 */
 
 enum {
-    THUMB_SEEKING,
-    THUMB_SEEKED,
-    THUMB_DROP_FIRST_FRAME,
-    THUMB_DONE,
+    THUMB_INIT,
+    THUMB_SEEKED = 0x1,
+    THUMB_VOUT   = 0x2,
+    THUMB_DONE   = 0x4,
 };
 
 typedef struct
@@ -72,10 +72,13 @@ typedef struct
     int state;
 
     char *thumbData;
+
     char *frameData;
+    unsigned frameSize;
 
     unsigned blackBorders;
     unsigned frameWidth;
+    unsigned frameHeight;
     unsigned thumbHeight;
     unsigned thumbPitch;
 
@@ -83,6 +86,95 @@ typedef struct
     pthread_cond_t doneCondVar;
 } thumbnailer_sys_t;
 
+static unsigned
+thumbnailer_setup(void **opaque, char *chroma,
+                  unsigned *width, unsigned *height,
+                  unsigned *pitches,
+                  unsigned *lines)
+{
+    thumbnailer_sys_t *sys = *opaque;
+
+    unsigned videoWidth = *width, videoHeight = *height;
+    strcpy(chroma, "RGBA");
+
+    LOGD("Video dimensions: %ix%i.\n", videoWidth, videoHeight );
+
+    /* VLC could not tell us the size */
+    if( videoWidth == 0 || videoHeight == 0 )
+    {
+        LOGE("Could not find the video dimensions.\n");
+        goto end;
+    }
+
+    if( videoWidth < THUMBNAIL_MIN_WIDTH || videoHeight < THUMBNAIL_MIN_HEIGHT
+        || videoWidth > THUMBNAIL_MAX_WIDTH || videoHeight > THUMBNAIL_MAX_HEIGHT )
+    {
+        LOGE("Wrong video dimensions.\n");
+        goto end;
+    }
+
+    /* Compute the size parameters of the frame to generate. */
+    unsigned thumbWidth  = sys->frameWidth;
+    unsigned thumbHeight = sys->frameHeight;
+    const float inputAR = (float)videoWidth / videoHeight;
+    const float screenAR = (float)sys->frameWidth / sys->frameHeight;
+
+    /* Most of the cases, video is wider than tall */
+    if (screenAR < inputAR)
+    {
+        thumbHeight = (float)sys->frameWidth / inputAR + 1;
+        sys->blackBorders = ( (sys->frameHeight - thumbHeight) / 2 ) * sys->frameWidth;
+    }
+    else
+    {
+        LOGD("Weird aspect Ratio.\n");
+        thumbWidth = (float)sys->frameHeight * inputAR;
+        sys->blackBorders = (sys->frameWidth - thumbWidth) / 2;
+    }
+
+    sys->thumbPitch  = thumbWidth * PIXEL_SIZE;
+    sys->thumbHeight = thumbHeight;
+
+    /* Allocate the memory to store the frames. */
+    size_t thumbSize = sys->thumbPitch * (sys->thumbHeight+1);
+    sys->thumbData = malloc(thumbSize);
+    if (sys->thumbData == NULL)
+    {
+        LOGE("Could not allocate the memory to store the frame!");
+        goto end;
+    }
+
+    *width = thumbWidth;
+    *height = thumbHeight;
+    pitches[0] = sys->thumbPitch;
+    *lines = thumbHeight;
+
+    pthread_mutex_lock(&sys->doneMutex);
+    sys->state |= THUMB_VOUT;
+    pthread_cond_signal(&sys->doneCondVar);
+    pthread_mutex_unlock(&sys->doneMutex);
+
+    return 1;
+end:
+    pthread_mutex_lock(&sys->doneMutex);
+    sys->state |= THUMB_DONE;
+    pthread_cond_signal(&sys->doneCondVar);
+    pthread_mutex_unlock(&sys->doneMutex);
+    return 0;
+}
+
+static void
+thumbnailer_event(const libvlc_event_t *ev, void *opaque)
+{
+    thumbnailer_sys_t *sys = opaque;
+    if (ev->u.media_player_position_changed.new_position >= THUMBNAIL_POSITION)
+    {
+        pthread_mutex_lock(&sys->doneMutex);
+        sys->state |= THUMB_SEEKED;
+        pthread_cond_signal(&sys->doneCondVar);
+        pthread_mutex_unlock(&sys->doneMutex);
+    }
+}
 
 /**
  * Thumbnailer vout lock
@@ -105,12 +197,21 @@ static void thumbnailer_unlock(void *opaque, void *picture, void *const *pixels)
     /* If we have already received a thumbnail, or we are still seeking,
      * we skip this frame. */
     pthread_mutex_lock(&sys->doneMutex);
-    int state = sys->state;
-    if (state == THUMB_SEEKED)
-        sys->state = THUMB_DROP_FIRST_FRAME;
-    pthread_mutex_unlock(&sys->doneMutex);
-    if (state != THUMB_DROP_FIRST_FRAME)
+    if ((sys->state & THUMB_SEEKED|THUMB_VOUT) != (THUMB_SEEKED|THUMB_VOUT))
+    {
+        pthread_mutex_unlock(&sys->doneMutex);
         return;
+    }
+    pthread_mutex_unlock(&sys->doneMutex);
+
+    /* Allocate the memory to store the thumbnail. */
+    sys->frameSize = sys->frameWidth * sys->frameHeight * PIXEL_SIZE;
+    sys->frameData = calloc(sys->frameSize, 1);
+    if (sys->frameData == NULL)
+    {
+        LOGE("Could not allocate the memory to store the thumbnail!");
+        goto end;
+    }
 
     /* we have received our first thumbnail and we can exit. */
     const char *dataSrc = sys->thumbData;
@@ -124,9 +225,10 @@ static void thumbnailer_unlock(void *opaque, void *picture, void *const *pixels)
         dataSrc += sys->thumbPitch;
     }
 
+end:
     /* Signal that the thumbnail was created. */
     pthread_mutex_lock(&sys->doneMutex);
-    sys->state = THUMB_DONE;
+    sys->state |= THUMB_DONE;
     pthread_cond_signal(&sys->doneCondVar);
     pthread_mutex_unlock(&sys->doneMutex);
 }
@@ -150,7 +252,7 @@ Java_org_videolan_libvlc_util_VLCUtil_nativeGetThumbnail(JNIEnv *env,
     if (sys == NULL)
     {
         LOGE("Could not create the thumbnailer data structure!");
-        goto enomem;
+        return NULL;
     }
 
     /* Initialize the barrier. */
@@ -159,136 +261,66 @@ Java_org_videolan_libvlc_util_VLCUtil_nativeGetThumbnail(JNIEnv *env,
 
     /* Create a media player playing environment */
     libvlc_media_player_t *mp = libvlc_media_player_new_from_media(p_obj->u.p_m);
+    if (!mp)
+        goto end;
     libvlc_media_player_set_video_title_display(mp, libvlc_position_disable, 0);
 
-    /* Get the size of the video with the tracks information of the media. */
-    libvlc_media_track_t **tracks;
-    libvlc_media_parse(p_obj->u.p_m);
-    int nbTracks = libvlc_media_tracks_get(p_obj->u.p_m, &tracks);
-
-    /* Parse the results */
-    unsigned videoWidth = 0, videoHeight = 0;
-    bool hasVideoTrack = false;
-    for (unsigned i = 0; i < nbTracks; ++i)
-        if (tracks[i]->i_type == libvlc_track_video)
-        {
-            videoWidth = tracks[i]->video->i_width;
-            videoHeight = tracks[i]->video->i_height;
-            hasVideoTrack = true;
-            break;
-        }
-
-    libvlc_media_tracks_release(tracks, nbTracks);
-
-    /* Abort if we have not found a video track. */
-    if (!hasVideoTrack)
-    {
-        LOGE("Could not find any video track in this file.\n");
-        goto end;
-    }
-
-    LOGD("Video dimensions: %ix%i.\n", videoWidth, videoHeight );
-
-    /* VLC could not tell us the size */
-    if( videoWidth == 0 || videoHeight == 0 )
-    {
-        LOGE("Could not find the video dimensions.\n");
-        goto end;
-    }
-
-    if( videoWidth < THUMBNAIL_MIN_WIDTH || videoHeight < THUMBNAIL_MIN_HEIGHT
-        || videoWidth > THUMBNAIL_MAX_WIDTH || videoHeight > THUMBNAIL_MAX_HEIGHT )
-    {
-        LOGE("Wrong video dimensions.\n");
-        goto end;
-    }
-
-    /* Compute the size parameters of the frame to generate. */
-    unsigned thumbWidth  = frameWidth;
-    unsigned thumbHeight = frameHeight;
-    const float inputAR = (float)videoWidth / videoHeight;
-    const float screenAR = (float)frameWidth / frameHeight;
-
-    /* Most of the cases, video is wider than tall */
-    if (screenAR < inputAR)
-    {
-        thumbHeight = (float)frameWidth / inputAR + 1;
-        sys->blackBorders = ( (frameHeight - thumbHeight) / 2 ) * frameWidth;
-    }
-    else
-    {
-        LOGD("Weird aspect Ratio.\n");
-        thumbWidth = (float)frameHeight * inputAR;
-        sys->blackBorders = (frameWidth - thumbWidth) / 2;
-    }
-
-    sys->thumbPitch  = thumbWidth * PIXEL_SIZE;
-    sys->thumbHeight = thumbHeight;
-    sys->frameWidth  = frameWidth;
-
-    /* Allocate the memory to store the frames. */
-    size_t thumbSize = sys->thumbPitch * (sys->thumbHeight+1);
-    sys->thumbData = malloc(thumbSize);
-    if (sys->thumbData == NULL)
-    {
-        LOGE("Could not allocate the memory to store the frame!");
-        goto end;
-    }
-
-    /* Allocate the memory to store the thumbnail. */
-    unsigned frameSize = frameWidth * frameHeight * PIXEL_SIZE;
-    sys->frameData = calloc(frameSize, 1);
-    if (sys->frameData == NULL)
-    {
-        LOGE("Could not allocate the memory to store the thumbnail!");
-        goto end;
-    }
-
+    sys->frameWidth = frameWidth;
+    sys->frameHeight = frameHeight;
     /* Set the video format and the callbacks. */
-    libvlc_video_set_format(mp, "RGBA", thumbWidth, thumbHeight, sys->thumbPitch);
     libvlc_video_set_callbacks(mp, thumbnailer_lock, thumbnailer_unlock,
                                NULL, (void*)sys);
-    sys->state = THUMB_SEEKING;
+    libvlc_video_set_format_callbacks(mp, thumbnailer_setup, NULL);
+
+    libvlc_event_attach(libvlc_media_player_event_manager(mp),
+                        libvlc_MediaPlayerPositionChanged,
+                        thumbnailer_event, sys);
 
     /* Play the media. */
     libvlc_media_player_play(mp);
     libvlc_media_player_set_position(mp, THUMBNAIL_POSITION);
 
-    const int wait_time = 50000;
-    const int max_attempts = 100;
-    for (int i = 0; i < max_attempts; ++i) {
-        if (libvlc_media_player_is_playing(mp) && libvlc_media_player_get_position(mp) >= THUMBNAIL_POSITION)
-            break;
-        usleep(wait_time);
-    }
-
     /* Wait for the thumbnail to be generated. */
     pthread_mutex_lock(&sys->doneMutex);
-    sys->state = THUMB_SEEKED;
     struct timespec deadline;
     clock_gettime(CLOCK_REALTIME, &deadline);
-    deadline.tv_sec += 10; /* amount of seconds before we abort thumbnailer */
-    do {
-        int ret = pthread_cond_timedwait(&sys->doneCondVar, &sys->doneMutex, &deadline);
-        if (ret == ETIMEDOUT)
-            break;
-    } while (sys->state != THUMB_DONE);
+    deadline.tv_sec += 3;
+
+    /* Wait for a VOUT for 3 seconds, some input format like *.TS make some time
+     * to initialize a VOUT */
+    int ret = 0;
+    while (!(sys->state & THUMB_VOUT) && ret != ETIMEDOUT)
+        ret = pthread_cond_timedwait(&sys->doneCondVar, &sys->doneMutex, &deadline);
+
+    if (sys->state & THUMB_VOUT)
+    {
+        ret = 0;
+        /* Wait an additional 7 seconds for a frame */
+        deadline.tv_sec += 7;
+        while (!(sys->state & THUMB_DONE) && ret != ETIMEDOUT)
+            ret = pthread_cond_timedwait(&sys->doneCondVar, &sys->doneMutex, &deadline);
+    }
+    else
+        LOGE("media has not VOUT");
     pthread_mutex_unlock(&sys->doneMutex);
 
     /* Stop and release the media player. */
     libvlc_media_player_stop(mp);
+    libvlc_event_detach(libvlc_media_player_event_manager(mp),
+                        libvlc_MediaPlayerPositionChanged,
+                        thumbnailer_event, sys);
     libvlc_media_player_release(mp);
 
-    if (sys->state == THUMB_DONE) {
+    if ((sys->state & THUMB_DONE) && sys->frameData) {
         /* Create the Java byte array to return the create thumbnail. */
-        byteArray = (*env)->NewByteArray(env, frameSize);
+        byteArray = (*env)->NewByteArray(env, sys->frameSize);
         if (byteArray == NULL)
         {
             LOGE("Could not allocate the Java byte array to store the frame!");
             goto end;
         }
 
-        (*env)->SetByteArrayRegion(env, byteArray, 0, frameSize,
+        (*env)->SetByteArrayRegion(env, byteArray, 0, sys->frameSize,
                 (jbyte *)sys->frameData);
     }
 
@@ -298,6 +330,5 @@ end:
     free(sys->frameData);
     free(sys->thumbData);
     free(sys);
-enomem:
     return byteArray;
 }
