@@ -48,19 +48,21 @@ import android.widget.PopupMenu;
 import android.widget.PopupMenu.OnMenuItemClickListener;
 
 import org.videolan.libvlc.util.AndroidUtil;
-import org.videolan.vlc.MediaLibrary;
-import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.PlaybackServiceFragment;
 import org.videolan.vlc.gui.SecondaryActivity;
+import org.videolan.vlc.gui.helpers.AudioUtil;
+import org.videolan.vlc.gui.helpers.MediaComparators;
+import org.videolan.vlc.gui.view.SwipeRefreshLayout;
+import org.videolan.vlc.media.MediaLibrary;
+import org.videolan.vlc.media.MediaUtils;
+import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.AndroidDevices;
-import org.videolan.vlc.util.Util;
+import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.WeakHandler;
-import org.videolan.vlc.widget.SwipeRefreshLayout;
 
-import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -197,6 +199,12 @@ public class AudioAlbumsSongsFragment extends PlaybackServiceFragment implements
         if (!AndroidDevices.isPhone())
             menu.setGroupVisible(R.id.phone_only, false);
         menu.findItem(R.id.audio_list_browser_play).setVisible(true);
+        //Hide delete if we cannot
+            AudioBrowserListAdapter adapter = mViewPager.getCurrentItem() == MODE_SONG ?
+                    mSongsAdapter : mAlbumsAdapter;
+            String location = adapter.getItem(position).mMediaList.get(0).getLocation();
+        menu.findItem(R.id.audio_list_browser_delete).setVisible(
+                FileUtils.canWrite(location));
     }
 
     @Override
@@ -279,13 +287,12 @@ public class AudioAlbumsSongsFragment extends PlaybackServiceFragment implements
                     public void run() {
                         for (int i = 0; i < mMediaList.size(); ++i) {
                             MediaWrapper media = mMediaList.get(i);
-                            mAlbumsAdapter.addSeparator(Util.getMediaReferenceArtist(activity, media), media);
-                            mAlbumsAdapter.add(Util.getMediaAlbum(activity, media), null, media);
-                            mSongsAdapter.addSeparator(Util.getMediaAlbum(activity, media), media);
+                            mAlbumsAdapter.addSeparator(MediaUtils.getMediaReferenceArtist(activity, media), media);
+                            mAlbumsAdapter.add(MediaUtils.getMediaAlbum(activity, media), null, media);
+                            mSongsAdapter.addSeparator(MediaUtils.getMediaAlbum(activity, media), media);
                         }
                         mSongsAdapter.sortByAlbum();
                         mAlbumsAdapter.notifyDataSetChanged();
-                        mSongsAdapter.notifyDataSetChanged();
                         mSwipeRefreshLayout.setRefreshing(false);
                     }
                 });
@@ -386,19 +393,16 @@ public class AudioAlbumsSongsFragment extends PlaybackServiceFragment implements
             switch (msg.what){
                 case DELETE_MEDIA:
                     AudioBrowserListAdapter.ListItem listItem = fragment.mSongsAdapter.getItem(msg.arg1);
-                    MediaWrapper media = listItem.mMediaList.get(0);
-                    final String path = media.getUri().getPath();
-                    fragment.mMediaLibrary.getMediaItems().remove(media);
-                    fragment.mSongsAdapter.removeMedia(media);
-                    fragment.mAlbumsAdapter.removeMedia(media);
-                    if (fragment.mService != null)
-                        fragment.mService.removeLocation(media.getLocation());
-                    fragment.mMediaLibrary.getMediaItems().remove(media);
-                    VLCApplication.runBackground(new Runnable() {
-                        public void run() {
-                            Util.recursiveDelete(VLCApplication.getAppContext(), new File(path));
-                        }
-                    });
+                    for (MediaWrapper media : listItem.mMediaList) {
+                        final String path = media.getUri().getPath();
+                        fragment.mMediaLibrary.getMediaItems().remove(media);
+                        fragment.mSongsAdapter.removeMedia(media);
+                        fragment.mAlbumsAdapter.removeMedia(media);
+                        if (fragment.mService != null)
+                            fragment.mService.removeLocation(media.getLocation());
+                        fragment.mMediaLibrary.getMediaItems().remove(media);
+                        FileUtils.asyncRecursiveDelete(path);
+                    }
                     break;
             }
         }
