@@ -24,11 +24,10 @@
 package org.videolan.vlc.gui.browser;
 
 import android.support.v7.widget.RecyclerView;
-import android.text.TextUtils;
 import android.view.View;
 
 import org.videolan.libvlc.Media;
-import org.videolan.vlc.MediaWrapper;
+import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.R;
 
 public class FilePickerAdapter extends BaseBrowserAdapter {
